@@ -35,11 +35,13 @@ If the current run successfully completes, `status` ends with
 `interrupting` and ends with `incomplete`.
 """
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
+from .format import format_with_config
 from .jobs import (
     create_job_dir,
     create_job_interactive_script_source,
     create_job_script_source,
     submit_job,
+    submit_job_dir,
 )
